@@ -1,13 +1,16 @@
 from pkg_resources import resource_filename
+from typing import List
 import jieba
 import msgpack
 import gzip
 
-DICT_FILENAME = resource_filename('wordfreq', 'data/jieba_zh.txt')
-ORIG_DICT_FILENAME = resource_filename('wordfreq', 'data/jieba_zh_orig.txt')
-SIMP_MAP_FILENAME = resource_filename('wordfreq', 'data/_chinese_mapping.msgpack.gz')
+DICT_FILENAME = resource_filename("wordfreq", "data/jieba_zh.txt")
+ORIG_DICT_FILENAME = resource_filename("wordfreq", "data/jieba_zh_orig.txt")
+SIMP_MAP_FILENAME = resource_filename("wordfreq", "data/_chinese_mapping.msgpack.gz")
 try:
-    SIMPLIFIED_MAP = msgpack.load(gzip.open(SIMP_MAP_FILENAME), raw=False, strict_map_key=False)
+    SIMPLIFIED_MAP = msgpack.load(
+        gzip.open(SIMP_MAP_FILENAME), raw=False, strict_map_key=False
+    )
 except TypeError:
     # work around incompatibility between pure-Python msgpack and C msgpack
     SIMPLIFIED_MAP = msgpack.load(gzip.open(SIMP_MAP_FILENAME), raw=False)
@@ -15,7 +18,7 @@ jieba_tokenizer = None
 jieba_orig_tokenizer = None
 
 
-def simplify_chinese(text):
+def simplify_chinese(text: str) -> str:
     """
     Convert Chinese text character-by-character to Simplified Chinese, for the
     purpose of looking up word frequencies.
@@ -29,7 +32,7 @@ def simplify_chinese(text):
     return text.translate(SIMPLIFIED_MAP).casefold()
 
 
-def jieba_tokenize(text, external_wordlist=False):
+def jieba_tokenize(text: str, external_wordlist: bool = False) -> List[str]:
     """
     Tokenize the given text into tokens whose word frequencies can probably
     be looked up. This uses Jieba, a word-frequency-based tokenizer.
@@ -58,6 +61,8 @@ def jieba_tokenize(text, external_wordlist=False):
         # those spans from the original text, even if it's in Traditional
         # Chinese
         tokens = []
-        for _token, start, end in jieba_tokenizer.tokenize(simplify_chinese(text), HMM=False):
+        for _token, start, end in jieba_tokenizer.tokenize(
+            simplify_chinese(text), HMM=False
+        ):
             tokens.append(text[start:end])
         return tokens
