@@ -1,33 +1,31 @@
-from pkg_resources import resource_filename
 import MeCab
 import unicodedata
-import os
+
+from typing import Dict, List
 
 
-# MeCab has fixed-sized buffers for many things, including the dictionary path
-MAX_PATH_LENGTH = 58
-
-
-def make_mecab_analyzer(lang):
+def make_mecab_analyzer(lang: str) -> MeCab.Tagger:
     """
     Get a MeCab analyzer object, given the language code of the language to
     analyze.
     """
-    if lang == 'ko':
+    if lang == "ko":
         import mecab_ko_dic
+
         return MeCab.Tagger(mecab_ko_dic.MECAB_ARGS)
-    elif lang == 'ja':
+    elif lang == "ja":
         import ipadic
+
         return MeCab.Tagger(ipadic.MECAB_ARGS)
     else:
-        raise ValueError("Can't run MeCab on language {lang}".format(lang))
+        raise ValueError(f"Can't run MeCab on language {lang}")
 
 
 # The constructed analyzers will go in this dictionary.
-MECAB_ANALYZERS = {}
+MECAB_ANALYZERS: Dict[str, MeCab.Tagger] = {}
 
 
-def mecab_tokenize(text, lang):
+def mecab_tokenize(text: str, lang: str) -> List[str]:
     """
     Use the mecab-python3 package to tokenize the given text. The `lang`
     must be 'ja' for Japanese or 'ko' for Korean.
@@ -40,10 +38,12 @@ def mecab_tokenize(text, lang):
         MECAB_ANALYZERS[lang] = make_mecab_analyzer(lang)
 
     analyzer = MECAB_ANALYZERS[lang]
-    text = unicodedata.normalize('NFKC', text.strip())
+    text = unicodedata.normalize("NFKC", text.strip())
     analyzed = analyzer.parse(text)
     if not analyzed:
         return []
-    return [line.split('\t')[0]
-            for line in analyzed.split('\n')
-            if line != '' and line != 'EOS']
+    return [
+        line.split("\t")[0]
+        for line in analyzed.split("\n")
+        if line != "" and line != "EOS"
+    ]
