@@ -2,6 +2,7 @@ import regex
 import unicodedata
 import logging
 import langcodes
+from typing import List
 from ftfy.fixes import uncurl_quotes
 
 from .language_info import (
@@ -9,7 +10,7 @@ from .language_info import (
     SPACELESS_SCRIPTS,
     EXTRA_JAPANESE_CHARACTERS,
 )
-from .preprocess import preprocess_text, smash_numbers
+from .preprocess import preprocess_text
 
 # Placeholders for CJK functions that we'll import on demand
 _mecab_tokenize = None
@@ -20,19 +21,19 @@ _WARNED_LANGUAGES = set()
 logger = logging.getLogger(__name__)
 
 
-def _make_spaceless_expr():
+def _make_spaceless_expr() -> str:
     scripts = sorted(SPACELESS_SCRIPTS)
-    pieces = [r'\p{IsIdeo}'] + [
-        r'\p{Script=%s}' % script_code for script_code in scripts
+    pieces = [r"\p{IsIdeo}"] + [
+        r"\p{Script=%s}" % script_code for script_code in scripts
     ]
-    return ''.join(pieces) + EXTRA_JAPANESE_CHARACTERS
+    return "".join(pieces) + EXTRA_JAPANESE_CHARACTERS
 
 
 SPACELESS_EXPR = _make_spaceless_expr()
 
 # All vowels that might appear at the start of a word in French or Catalan,
 # plus 'h' which would be silent and imply a following vowel sound.
-INITIAL_VOWEL_EXPR = '[AEHIOUYÁÉÍÓÚÀÈÌÒÙÂÊÎÔÛÅÏÖŒaehiouyáéíóúàèìòùâêîôûåïöœ]'
+INITIAL_VOWEL_EXPR = "[AEHIOUYÁÉÍÓÚÀÈÌÒÙÂÊÎÔÛÅÏÖŒaehiouyáéíóúàèìòùâêîôûåïöœ]"
 
 TOKEN_RE = regex.compile(
     r"""
@@ -148,9 +149,9 @@ TOKEN_RE = regex.compile(
 
     \w\w?'
 """.replace(
-        '<SPACELESS>', SPACELESS_EXPR
+        "<SPACELESS>", SPACELESS_EXPR
     ).replace(
-        '<VOWEL>', INITIAL_VOWEL_EXPR
+        "<VOWEL>", INITIAL_VOWEL_EXPR
     ),
     regex.V1 | regex.WORD | regex.VERBOSE,
 )
@@ -167,9 +168,9 @@ TOKEN_RE_WITH_PUNCTUATION = regex.compile(
       \X+? (?: @s? (?!w) | \b) |                            # Case 3
     \w\w?'                                                  # Case 4
 """.replace(
-        '<SPACELESS>', SPACELESS_EXPR
+        "<SPACELESS>", SPACELESS_EXPR
     ).replace(
-        '<VOWEL>', INITIAL_VOWEL_EXPR
+        "<VOWEL>", INITIAL_VOWEL_EXPR
     ),
     regex.V1 | regex.WORD | regex.VERBOSE,
 )
@@ -179,7 +180,7 @@ TOKEN_RE_WITH_PUNCTUATION = regex.compile(
 PUNCT_RE = regex.compile(r"[\p{punct}]+")
 
 
-def simple_tokenize(text, include_punctuation=False):
+def simple_tokenize(text: str, include_punctuation: bool = False) -> List[str]:
     """
     Tokenize the given text using a straightforward, Unicode-aware token
     expression.
@@ -207,17 +208,19 @@ def simple_tokenize(text, include_punctuation=False):
       tokens that are much too long, but the alternative is that every grapheme
       would end up in its own token, which is worse.
     """
-    text = unicodedata.normalize('NFC', text)
+    text = unicodedata.normalize("NFC", text)
     if include_punctuation:
-        return [
-            token.casefold()
-            for token in TOKEN_RE_WITH_PUNCTUATION.findall(text)
-        ]
+        return [token.casefold() for token in TOKEN_RE_WITH_PUNCTUATION.findall(text)]
     else:
         return [token.strip("'").casefold() for token in TOKEN_RE.findall(text)]
 
 
-def tokenize(text, lang, include_punctuation=False, external_wordlist=False):
+def tokenize(
+    text: str,
+    lang: str,
+    include_punctuation: bool = False,
+    external_wordlist: bool = False,
+) -> List[str]:
     """
     Tokenize this text in a way that's relatively simple but appropriate for
     the language. Strings that are looked up in wordfreq will be run through
@@ -257,16 +260,21 @@ def tokenize(text, lang, include_punctuation=False, external_wordlist=False):
     info = get_language_info(language)
     text = preprocess_text(text, language)
 
-    if info['tokenizer'] == 'mecab':
-        from wordfreq.mecab import mecab_tokenize as _mecab_tokenize
+    if info["tokenizer"] == "mecab":
+        from wordfreq.mecab import mecab_tokenize
+
+        _mecab_tokenize = mecab_tokenize
 
         # Get just the language code out of the Language object, so we can
         # use it to select a MeCab dictionary
+        assert language.language is not None
         tokens = _mecab_tokenize(text, language.language)
         if not include_punctuation:
             tokens = [token for token in tokens if not PUNCT_RE.match(token)]
-    elif info['tokenizer'] == 'jieba':
-        from wordfreq.chinese import jieba_tokenize as _jieba_tokenize
+    elif info["tokenizer"] == "jieba":
+        from wordfreq.chinese import jieba_tokenize
+
+        _jieba_tokenize = jieba_tokenize
 
         tokens = _jieba_tokenize(text, external_wordlist=external_wordlist)
         if not include_punctuation:
@@ -275,11 +283,11 @@ def tokenize(text, lang, include_punctuation=False, external_wordlist=False):
         # This is the default case where we use the regex tokenizer. First
         # let's complain a bit if we ended up here because we don't have an
         # appropriate tokenizer.
-        if info['tokenizer'] != 'regex' and lang not in _WARNED_LANGUAGES:
+        if info["tokenizer"] != "regex" and lang not in _WARNED_LANGUAGES:
             logger.warning(
                 "The language '{}' is in the '{}' script, which we don't "
                 "have a tokenizer for. The results will be bad.".format(
-                    lang, info['script']
+                    lang, info["script"]
                 )
             )
             _WARNED_LANGUAGES.add(lang)
@@ -289,8 +297,11 @@ def tokenize(text, lang, include_punctuation=False, external_wordlist=False):
 
 
 def lossy_tokenize(
-    text, lang, include_punctuation=False, external_wordlist=False
-):
+    text: str,
+    lang: str,
+    include_punctuation: bool = False,
+    external_wordlist: bool = False,
+) -> List[str]:
     """
     Get a list of tokens for this text, with largely the same results and
     options as `tokenize`, but aggressively normalize some text in a lossy way
@@ -298,13 +309,6 @@ def lossy_tokenize(
 
     In particular:
 
-    - Any sequence of 2 or more adjacent digits, possibly with intervening
-      punctuation such as a decimal point, will replace each digit with '0'
-      so that frequencies for numbers don't have to be counted separately.
-
-      This is similar to but not quite identical to the word2vec Google News
-      data, which replaces digits with '#' in tokens with more than one digit.
-
     - In Chinese, unless Traditional Chinese is specifically requested using
       'zh-Hant', all characters will be converted to Simplified Chinese.
 
@@ -316,9 +320,11 @@ def lossy_tokenize(
     info = get_language_info(lang)
     tokens = tokenize(text, lang, include_punctuation, external_wordlist)
 
-    if info['lookup_transliteration'] == 'zh-Hans':
-        from wordfreq.chinese import simplify_chinese as _simplify_chinese
+    if info["lookup_transliteration"] == "zh-Hans":
+        from wordfreq.chinese import simplify_chinese
+
+        _simplify_chinese = simplify_chinese
 
         tokens = [_simplify_chinese(token) for token in tokens]
 
-    return [uncurl_quotes(smash_numbers(token)) for token in tokens]
+    return [uncurl_quotes(token) for token in tokens]
